@@ -7,7 +7,7 @@ Attean::API - Utility package for loading all Attean role packages.
 
 =head1 VERSION
 
-This document describes Attean::API version 0.011
+This document describes Attean::API version 0.014
 
 =head1 SYNOPSIS
 
@@ -25,16 +25,17 @@ in the Attean::API namespace.
 
 =cut
 
-package Attean::API::ResultOrTerm 0.011 {
+package Attean::API::ResultOrTerm 0.014 {
 	use Moo::Role;
 }
 
-package Attean::API::BlankOrIRI 0.011 {
+package Attean::API::BlankOrIRI 0.014 {
 	use Moo::Role;
 }
 
-package Attean::API::TermOrVariable 0.011 {
+package Attean::API::TermOrVariable 0.014 {
 	use Moo::Role;
+	use Scalar::Util qw(blessed);
 	use Sub::Install;
 	use Sub::Util qw(set_subname);
 	use namespace::clean;
@@ -46,6 +47,23 @@ package Attean::API::TermOrVariable 0.011 {
 		return ($a->as_string eq $b->as_string);
 	}
 	
+	sub apply_binding {
+		my $self	= shift;
+		my $class	= ref($self);
+		my $bind	= shift;
+		if ($self->does('Attean::API::Variable')) {
+			my $name	= $self->value;
+			my $replace	= $bind->value($name);
+			if (defined($replace) and blessed($replace)) {
+				return $replace;
+			} else {
+				return $self;
+			}
+		} else {
+			return $self;
+		}
+	}
+
 	BEGIN {
 		my %types	= (
 			variable	=> 'Variable',
@@ -65,12 +83,12 @@ package Attean::API::TermOrVariable 0.011 {
 	}
 }
 
-package Attean::Mapper 0.011 {
+package Attean::Mapper 0.014 {
 	use Moo::Role;
 	requires 'map'; # my $that = $object->map($this)
 }
 
-package Attean::API::Variable 0.011 {
+package Attean::API::Variable 0.014 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo::Role;
@@ -97,7 +115,7 @@ Returns a string representation of the variable.'
 	
 }
 
-package Attean::API::CanonicalizingBindingSet 0.011 {
+package Attean::API::CanonicalizingBindingSet 0.014 {
 	use Moo::Role;
 	use Attean::RDF;
 	use namespace::clean;
@@ -193,7 +211,7 @@ package Attean::API::CanonicalizingBindingSet 0.011 {
 	}
 }
 
-package Attean::API 0.011 {
+package Attean::API 0.014 {
 	use Attean::API::Term;
 	use Attean::API::Store;
 	use Attean::API::Model;
