@@ -7,7 +7,7 @@ Attean::API::Parser - Parser role
 
 =head1 VERSION
 
-This document describes Attean::API::Parser version 0.013
+This document describes Attean::API::Parser version 0.014
 
 =head1 DESCRIPTION
 
@@ -52,20 +52,43 @@ parsing.
 
 use Type::Tiny::Role;
 
-package Attean::API::Parser 0.013 {
+package Attean::API::Parser 0.014 {
 	use Moo::Role;
-	use Types::Standard qw(CodeRef);
+	use Types::Standard qw(CodeRef Bool);
 	use namespace::clean;
 	
 	has 'handler' => (is => 'rw', isa => CodeRef, default => sub { sub {} });
+	has 'lazy_iris' => (is => 'rw', isa => Bool, default => 0);
 	
 	requires 'canonical_media_type'; # => (is => 'ro', isa => 'Str', init_arg => undef);
 	requires 'media_types'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
 	requires 'handled_type'; # => (is => 'ro', isa => 'Type::Tiny', init_arg => undef);
 	requires 'file_extensions'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
+	
+=item C<< new_iri( value => $value ) >>
+
+Constructs and returns a new L<Attean::IRI> object, respecting the parser's
+C<lazy_iris> attribute.
+=cut
+
+	sub new_iri {
+		my $self	= shift;
+		my %args;
+		if ($self->lazy_iris) {
+			$args{lazy}	= 1;
+		} else {
+			$args{lazy}	= 0;
+		}
+		if (scalar(@_) == 1) {
+			$args{value}	= shift;
+		} else {
+			%args	= (%args, @_);
+		}
+		return Attean::IRI->new(%args);
+	}
 }
 
-package Attean::API::AbbreviatingParser 0.013 {
+package Attean::API::AbbreviatingParser 0.014 {
 	use Moo::Role;
 	use Types::Standard qw(InstanceOf Maybe);
 	use URI::NamespaceMap;
@@ -77,7 +100,7 @@ package Attean::API::AbbreviatingParser 0.013 {
 	has 'namespaces'	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']]);
 }
 
-package Attean::API::PushParser 0.013 {
+package Attean::API::PushParser 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 
@@ -141,7 +164,7 @@ package Attean::API::PushParser 0.013 {
 	}
 }
 
-package Attean::API::PullParser 0.013 {
+package Attean::API::PullParser 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -183,7 +206,7 @@ package Attean::API::PullParser 0.013 {
 	}
 }
 
-package Attean::API::AtOnceParser 0.013 {
+package Attean::API::AtOnceParser 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -244,7 +267,7 @@ package Attean::API::AtOnceParser 0.013 {
 	
 }
 
-package Attean::API::TermParser 0.013 {
+package Attean::API::TermParser 0.014 {
 	# Parser returns objects that conform to Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -254,7 +277,7 @@ package Attean::API::TermParser 0.013 {
 	}
 }
 
-package Attean::API::TripleParser 0.013 {
+package Attean::API::TripleParser 0.014 {
 	# Parser returns objects that conform to Attean::API::Triple
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -264,7 +287,7 @@ package Attean::API::TripleParser 0.013 {
 	}
 }
 
-package Attean::API::QuadParser 0.013 {
+package Attean::API::QuadParser 0.014 {
 	# Parser returns objects that conform to Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -274,7 +297,7 @@ package Attean::API::QuadParser 0.013 {
 	}
 }
 
-package Attean::API::MixedStatementParser 0.013 {
+package Attean::API::MixedStatementParser 0.014 {
 	# Parser returns objects that conform to either Attean::API::Triple or Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -284,7 +307,7 @@ package Attean::API::MixedStatementParser 0.013 {
 	}
 }
 
-package Attean::API::ResultOrTermParser 0.013 {
+package Attean::API::ResultOrTermParser 0.014 {
 	# Parser returns objects that conform to either Attean::API::Result or Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -294,7 +317,7 @@ package Attean::API::ResultOrTermParser 0.013 {
 	}
 }
 
-package Attean::API::ResultParser 0.013 {
+package Attean::API::ResultParser 0.014 {
 	# Parser returns objects that conform to Attean::API::Result
 	use Moo::Role;
 	with 'Attean::API::Parser';
