@@ -7,7 +7,7 @@ Attean::API::Serializer - Serializer role
 
 =head1 VERSION
 
-This document describes Attean::API::Serializer version 0.013
+This document describes Attean::API::Serializer version 0.014
 
 =head1 DESCRIPTION
 
@@ -68,8 +68,9 @@ UTF-8 encoded byte string.
 
 use Type::Tiny;
 
-package Attean::API::Serializer 0.013 {
+package Attean::API::Serializer 0.014 {
 	use Moo::Role;
+	use Carp qw(confess);
 	
 	requires 'canonical_media_type'; # => (is => 'ro', isa => 'Str', init_arg => undef);
 	requires 'media_types'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
@@ -78,6 +79,18 @@ package Attean::API::Serializer 0.013 {
 	requires 'serialize_iter_to_io';		# serialize_iter_to_io($io, $iter)
 	requires 'serialize_iter_to_bytes';		# $data = serialize_iter_to_bytes($iter)
 
+	before 'serialize_iter_to_io' => sub {
+		my $self	= shift;
+		my $io		= shift || confess "No filehandle passed to serialize_iter_to_io";
+		my $iter	= shift || confess "No iterator passed to serialize_iter_to_io";
+	};
+
+	before 'serialize_iter_to_bytes' => sub {
+		my $self	= shift;
+		my $iter	= shift || confess "No iterator passed to serialize_iter_to_bytes";
+	};
+
+
 	sub serialize_list_to_io {
 		my $self	= shift;
 		my $io		= shift;
@@ -92,7 +105,7 @@ package Attean::API::Serializer 0.013 {
 	}
 }
 
-package Attean::API::AbbreviatingSerializer 0.013 {
+package Attean::API::AbbreviatingSerializer 0.014 {
 	# Serializer that can make use of a base IRI and/or prefix IRI mappings
 	use Moo::Role;
 	use Types::Standard qw(InstanceOf ConsumerOf Maybe);
@@ -104,13 +117,13 @@ package Attean::API::AbbreviatingSerializer 0.013 {
 	has namespaces	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
 }
 
-package Attean::API::AppendableSerializer 0.013 {
+package Attean::API::AppendableSerializer 0.014 {
 	# Serializer for a format that allows multiple serialization calls to be appended and remain syntactically valid
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 }
 
-package Attean::API::TermSerializer 0.013 {
+package Attean::API::TermSerializer 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -119,7 +132,7 @@ package Attean::API::TermSerializer 0.013 {
 	}
 }
 
-package Attean::API::TripleSerializer 0.013 {
+package Attean::API::TripleSerializer 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -128,7 +141,7 @@ package Attean::API::TripleSerializer 0.013 {
 	}
 }
 
-package Attean::API::QuadSerializer 0.013 {
+package Attean::API::QuadSerializer 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -138,7 +151,7 @@ package Attean::API::QuadSerializer 0.013 {
 	}
 }
 
-package Attean::API::MixedStatementSerializer 0.013 {
+package Attean::API::MixedStatementSerializer 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -148,7 +161,7 @@ package Attean::API::MixedStatementSerializer 0.013 {
 	}
 }
 
-package Attean::API::ResultSerializer 0.013 {
+package Attean::API::ResultSerializer 0.014 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
