@@ -7,7 +7,7 @@ Attean::ListIterator - Iterator implementation backed by a list/array of values
 
 =head1 VERSION
 
-This document describes Attean::ListIterator version 0.013
+This document describes Attean::ListIterator version 0.014
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ iterator.
 
 =cut
 
-package Attean::ListIterator 0.013 {
+package Attean::ListIterator 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Type::Tiny::Role;
@@ -97,6 +97,18 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 		return $item;
 	}
 
+=item C<< size >>
+
+Returns the number of elements still remaining in the iterator until it is
+fully consumed or until C<< reset >> is called.
+
+=cut
+
+	sub size {
+		my $self	= shift;
+		return scalar(@{ $self->values }) - $self->current;
+	}
+	
 	with 'Attean::API::RepeatableIterator';
 }
 
