@@ -8,7 +8,7 @@ Attean::Plan - Representation of SPARQL query plan operators
 
 =head1 VERSION
 
-This document describes Attean::Plan version 0.013
+This document describes Attean::Plan version 0.014
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,7 @@ Evaluates a quad pattern against the model.
 
 =cut
 
-package Attean::Plan::Quad 0.013 {
+package Attean::Plan::Quad 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed reftype);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -137,7 +137,7 @@ Evaluates a join (natural-, anti-, or left-) using a nested loop.
 
 =cut
 
-package Attean::Plan::NestedLoopJoin 0.013 {
+package Attean::Plan::NestedLoopJoin 0.014 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -226,7 +226,7 @@ Evaluates a join (natural-, anti-, or left-) using a hash join.
 
 =cut
 
-package Attean::Plan::HashJoin 0.013 {
+package Attean::Plan::HashJoin 0.014 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -367,7 +367,7 @@ package Attean::Plan::HashJoin 0.013 {
 
 =cut
 
-package Attean::Plan::Construct 0.013 {
+package Attean::Plan::Construct 0.014 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use Types::Standard qw(Str ArrayRef ConsumerOf InstanceOf);
@@ -458,7 +458,7 @@ package Attean::Plan::Construct 0.013 {
 
 =cut
 
-package Attean::Plan::Describe 0.013 {
+package Attean::Plan::Describe 0.014 {
 	use Moo;
 	use Attean::RDF;
 	use List::MoreUtils qw(all);
@@ -544,7 +544,7 @@ named variable binding.
 
 =cut
 
-package Attean::Plan::EBVFilter 0.013 {
+package Attean::Plan::EBVFilter 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ConsumerOf);
@@ -603,7 +603,7 @@ ordering.
 
 =cut
 
-package Attean::Plan::Merge 0.013 {
+package Attean::Plan::Merge 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ArrayRef ConsumerOf);
@@ -632,7 +632,7 @@ Evaluates a set of sub-plans, returning the union of results.
 
 =cut
 
-package Attean::Plan::Union 0.013 {
+package Attean::Plan::Union 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
@@ -703,7 +703,7 @@ expressions, binding the produced values to new variables.
 
 =cut
 
-package Attean::Plan::Extend 0.013 {
+package Attean::Plan::Extend 0.014 {
 	use Moo;
 	use Encode;
 	use Data::UUID;
@@ -1297,7 +1297,7 @@ hash of already-seen results.
 
 =cut
 
-package Attean::Plan::HashDistinct 0.013 {
+package Attean::Plan::HashDistinct 0.014 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1325,7 +1325,7 @@ filtering out sequential duplicates.
 
 =cut
 
-package Attean::Plan::Unique 0.013 {
+package Attean::Plan::Unique 0.014 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1360,7 +1360,7 @@ number of results ("offset") and limiting the total number of returned results
 
 =cut
 
-package Attean::Plan::Slice 0.013 {
+package Attean::Plan::Slice 0.014 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -1401,7 +1401,7 @@ of variable bindings in each result.
 
 =cut
 
-package Attean::Plan::Project 0.013 {
+package Attean::Plan::Project 0.014 {
 	use Moo;
 	with 'Attean::API::BindingSubstitutionPlan', 'Attean::API::UnaryQueryTree';
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1478,7 +1478,7 @@ sorting is applied.
 
 =cut
 
-package Attean::Plan::OrderBy 0.013 {
+package Attean::Plan::OrderBy 0.014 {
 	use Moo;
 	use Types::Standard qw(HashRef ArrayRef InstanceOf Bool Str);
 	use namespace::clean;
@@ -1548,7 +1548,7 @@ Evaluates a SPARQL query against a remove endpoint.
 
 =cut
 
-package Attean::Plan::Service 0.013 {
+package Attean::Plan::Service 0.014 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool Str);
 	use namespace::clean;
@@ -1580,7 +1580,7 @@ Returns a constant set of results.
 
 =cut
 
-package Attean::Plan::Table 0.013 {
+package Attean::Plan::Table 0.014 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -1632,11 +1632,84 @@ package Attean::Plan::Table 0.013 {
 	}
 }
 
+=item * L<Attean::Plan::Iterator>
+
+Returns a constant set of results.
+
+Be aware that if the iterator being wrapped is not repeatable (consuming the
+L<Attean::API::RepeatableIterator> role), then this plan may only be evaluated
+once.
+
+A size estimate may be given if it is available. If the iterator is an
+L<Attean::ListIterator>, the size of that iterator will be used.
+
+=cut
+
+package Attean::Plan::Iterator 0.014 {
+	use Moo;
+	use Types::Standard qw(ArrayRef ConsumerOf Int);
+	use namespace::clean;
+
+	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
+
+	has iterator		=> (is => 'ro', isa => ConsumerOf['Attean::API::ResultIterator']);
+	has size_estimate	=> (is => 'lazy', isa => Int, predicate => 1);
+
+	sub _build_size_estimate {
+		my $self = shift;
+		my $iter = $self->iterator;
+		if ($iter->isa('Attean::ListIterator')) {
+			return $iter->size;
+		}
+	}
+
+
+	sub tree_attributes { return qw(iterator) };
+	sub plan_as_string {
+		my $self	= shift;
+		my $level	= shift;
+		my $indent	= '  ' x ($level + 1);
+		my $string = 'Iterator (';
+		$string	.= join(', ', map { "?$_" } @{ $self->in_scope_variables });
+		if ($self->has_size_estimate) {
+			$string .= ' with ' . $self->size_estimate . ' elements';
+		}
+		$string	.= ')';
+		return $string;
+	}
+	
+	sub BUILDARGS {
+		my $class		= shift;
+		my %args		= @_;
+		my $vars		= $args{iterator}->variables;
+		
+		if (exists $args{in_scope_variables}) {
+			Carp::confess "in_scope_variables is computed automatically, and must not be specified in the $class constructor";
+		}
+		$args{in_scope_variables}	= $vars;
+
+		return $class->SUPER::BUILDARGS(%args);
+	}
+	
+	sub impl {
+		my $self	= shift;
+		my $model	= shift;
+		my $iter	= $self->iterator;
+
+		return sub {
+			if ($iter->does('Attean::API::RepeatableIterator')) {
+				$iter->reset;
+			}
+			return $iter;
+		};
+	}
+}
+
 =item * L<Attean::Plan::ALPPath>
 
 =cut
 
-package Attean::Plan::ALPPath 0.013 {
+package Attean::Plan::ALPPath 0.014 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1788,7 +1861,7 @@ package Attean::Plan::ALPPath 0.013 {
 	}
 }
 
-package Attean::Plan::ZeroOrOnePath 0.013 {
+package Attean::Plan::ZeroOrOnePath 0.014 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1887,7 +1960,7 @@ results were produced by evaluating the sub-plan.
 
 =cut
 
-package Attean::Plan::Exists 0.013 {
+package Attean::Plan::Exists 0.014 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -1917,7 +1990,7 @@ package Attean::Plan::Exists 0.013 {
 
 =cut
 
-package Attean::Plan::Aggregate 0.013 {
+package Attean::Plan::Aggregate 0.014 {
 	use Moo;
 	use Encode;
 	use Data::UUID;
@@ -2146,7 +2219,7 @@ package Attean::Plan::Aggregate 0.013 {
 	}
 }
 
-package Attean::Plan::Sequence 0.013 {
+package Attean::Plan::Sequence 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2171,7 +2244,7 @@ package Attean::Plan::Sequence 0.013 {
 	}
 }
 
-package Attean::Plan::Clear 0.013 {
+package Attean::Plan::Clear 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2208,7 +2281,7 @@ package Attean::Plan::Clear 0.013 {
 	}
 }
 
-package Attean::Plan::Drop 0.013 {
+package Attean::Plan::Drop 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2243,7 +2316,7 @@ package Attean::Plan::Drop 0.013 {
 	}
 }
 
-package Attean::Plan::TripleTemplateToModelQuadMethod 0.013 {
+package Attean::Plan::TripleTemplateToModelQuadMethod 0.014 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf Str ArrayRef HashRef);
@@ -2319,7 +2392,7 @@ package Attean::Plan::TripleTemplateToModelQuadMethod 0.013 {
 	}
 }
 
-package Attean::Plan::Load 0.013 {
+package Attean::Plan::Load 0.014 {
 	use Moo;
 	use Encode;
 	use LWP::UserAgent;
