@@ -4,7 +4,7 @@ Attean::RDF - Utility package for exporting shorthand functions for constructing
 
 =head1 VERSION
 
-This document describes Attean::RDF version 0.010
+This document describes Attean::RDF version 0.014
 
 =head1 SYNOPSIS
 
@@ -31,7 +31,7 @@ by default).
 
 =cut
 
-package Attean::RDF 0.010 {
+package Attean::RDF 0.014 {
 	use v5.14;
 	use warnings;
 
@@ -41,7 +41,7 @@ package Attean::RDF 0.010 {
 	use namespace::clean;
 
 	our @ISA	= qw(Exporter);
-	our @EXPORT	= qw(iri blank literal dtliteral langliteral variable triple quad triplepattern);
+	our @EXPORT	= qw(iri blank literal dtliteral langliteral variable triple quad triplepattern quadpattern);
 
 =item C<< variable( $value ) >>
 
@@ -134,8 +134,18 @@ C<< Attean::Quad->new( @terms ) >>
 	sub quad {
 		return Attean::Quad->new(@_);
 	}
-}
 
+=item C<< quadpattern( @terms ) >>
+
+C<< Attean::QuadPattern->new( @terms ) >>
+
+=cut
+
+	sub quadpattern {
+		return Attean::QuadPattern->new(@_);
+	}
+}
+	
 1;
 
 __END__
@@ -161,7 +171,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 Gregory Todd Williams.
+Copyright (c) 2014--2016 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
