@@ -4,7 +4,7 @@ AtteanX::Serializer::NQuads - N-Triples Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NQuads version 0.013
+This document describes AtteanX::Serializer::NQuads version 0.014
 
 =head1 SYNOPSIS
 
@@ -14,7 +14,7 @@ This document describes AtteanX::Serializer::NQuads version 0.013
 
 =head1 DESCRIPTION
 
-...
+Serializes triples and quads into the RDF 1.1 N-Quads format.
 
 =head1 ATTRIBUTES
 
@@ -28,9 +28,16 @@ This document describes AtteanX::Serializer::NQuads version 0.013
 
 =over 4
 
+=item C<< serialize_iter_to_io( $fh, $iterator ) >>
+
+=item C<< serialize_iter_to_bytes( $fh ) >>
+
 =cut
 
-package AtteanX::Serializer::NQuads 0.013 {
+use v5.14;
+use warnings;
+
+package AtteanX::Serializer::NQuads 0.014 {
 	use Moo;
 	use Types::Standard qw(Str ArrayRef);
 	use Encode qw(encode);
@@ -66,6 +73,10 @@ __END__
 Please report any bugs or feature requests to through the GitHub web interface
 at L<https://github.com/kasei/perlrdf/issues>.
 
+=head1 SEE ALSO
+
+L<https://www.w3.org/TR/n-quads/>
+
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
